@@ -2,8 +2,6 @@
 """
 Integration (not unit) tests for pylast.py
 """
-import unittest
-
 import pylast
 from flaky import flaky
 
@@ -26,7 +24,7 @@ class TestPyLastWithLibreFm(PyLastTestCase):
         name = artist.get_name()
 
         # Assert
-        self.assertEqual(name, "Radiohead")
+        assert name == "Radiohead"
 
     def test_repr(self):
         # Arrange
@@ -40,7 +38,3 @@ class TestPyLastWithLibreFm(PyLastTestCase):
 
         # Assert
         self.assert_startswith(representation, "pylast.LibreFMNetwork(")
-
-
-if __name__ == "__main__":
-    unittest.main(failfast=True)
