@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
-import mock
-import pytest
+from unittest import mock
 
 import pylast
+import pytest
 
 
 def mock_network():
